Skip to content

Commit 78bfe12

Browse files
authored
fix compilation warning (deepmodeling#7215)
1 parent 3a996b6 commit 78bfe12

2 files changed

Lines changed: 2 additions & 2 deletions

File tree

source/source_lcao/module_gint/kernel/gemm_nn_vbatch.cuh

Lines changed: 1 addition & 1 deletion
Original file line numberDiff line numberDiff line change
@@ -273,7 +273,7 @@ static __global__ void vbatched_gemm_nn_kernel(const int* M,
273273
const int* global_ldc,
274274
const T* alpha)
275275
{
276-
extern __shared__ __align__(sizeof(T)) unsigned char smem[];
276+
extern __shared__ __align__(sizeof(double)) unsigned char smem[];
277277
T* shared_mem = reinterpret_cast<T*>(smem);
278278

279279
int batchid = blockIdx.z;

source/source_lcao/module_gint/kernel/gemm_tn_vbatch.cuh

Lines changed: 1 addition & 1 deletion
Original file line numberDiff line numberDiff line change
@@ -273,7 +273,7 @@ static __global__ void vbatched_gemm_nt_kernel(const int* M,
273273
const int* global_ldc,
274274
const T* alpha)
275275
{
276-
extern __shared__ __align__(sizeof(T)) unsigned char smem[];
276+
extern __shared__ __align__(sizeof(double)) unsigned char smem[];
277277
T* shared_mem = reinterpret_cast<T*>(smem);
278278

279279
int batchid = blockIdx.z;

0 commit comments

Comments
 (0)